.. _references:

References
==========

.. [Hill1960] Hill, T.L. *An introduction to statistical mechanics*;
   Addison-Wesley: Reading, MA, 1960

.. [McQuarrie1997] McQuarrie, D.A.; Simons J.D. *Physical Chemistry, A molecular
   approach*; University Science Books: Sausalito, CA 94965, US, 1997.
